==> ocstore25_6_20.zip: OcStore/CS_Entity/CS_KanpaWater.cpp <==
#include "CS_KanpaWater.h"
#include "CS_Kanpa.h"
const int CS_KanpaSTATENAME_WATER = ++entityStateID;
CS_KanpaWater::CS_KanpaWater()
{
	enable = true;
	stateID = CS_KanpaSTATENAME_WATER;
	o2_counter_max = 20;
}

void CS_KanpaWater::State()
{
	auto we = e.lock();
	if (!we)
		return;

	auto mychar = std::static_pointer_cast<CS_Kanpa>(we);
	auto& stateGravity = mychar->stateGravity2;
	mychar->SetPhysice(we->cbRect.inWater);
	if (we->cbRect.pxaBottom == 0x12)
		mychar->SetPhysice(true);

	//ˮˮЧ
	if (we->cbRect.inWater)
	{
		o2_show = true;
		o2_hide_counter = 60;
		if (fallToWater && setSplash && we->vy >= stateGravity.GetMaxFallSpeed() / 2)
		{
			//ˮ
			auto nE = we->gameFunc->GameCreateEntity(L"pe_splash");
			nE->x = we->x;
			nE->y = we->y;
			//ҽ
			if (we->cbRect.inLava)
				nE->color = RGBA(0xff, 0, 0, 0xff);
			we->gameFunc->SetEntity(we, nE);
			fallToWater = false;
		}
		else
		{
			//ٶδﵽȻˮ
			setSplash = false;
		}
		//ֵ
		if (o2_counter > 0)
			o2_counter--;
		if (o2_counter == 0)
		{
			o2_counter = o2_counter_max;
			if (o2 > 0)
				o2--;
		}
		if (o2 == 0)
		{
			//Ϣ
			mychar->ChangeState(mychar->stateDrown.GetStateID());
			if (we->gameFunc->StartEvent)
			{
				we->gameFunc->StopMusic();
				we->gameFunc->StartEvent(we->gameFunc->gameScript, L"Drown", L"tBoot");
			}
		}
	}
	else
	{
		//ˮ
		fallToWater = true;
		setSplash = true;
		//ʾ
		o2 = 100;
		if (o2_hide_counter > 0)
			o2_hide_counter--;
		if (o2_hide_counter == 0)
			o2_show = false;
	}
	//UI
	if (we->gameFunc)
	{
		int playerIndex = we->gameFunc->GetPlayerIndex(we->gameFunc->game, we);
		if (playerIndex < 0)
			return;
		auto& ui = *we->gameFunc->GetPlayerUIData(we->gameFunc->gameUI, playerIndex);
		ui.o2_show = o2_show;
		ui.o2 = o2;
		ui.o2_effect = we->cbRect.inWater;
	}
}

==> ocstore25_7_4.zip: OcStore/CS_Entity/CS_KanpaWater.cpp <==
#include "CS_KanpaWater.h"
#include "CS_Kanpa.h"
const int CS_KanpaSTATENAME_WATER = ++entityStateID;
CS_KanpaWater::CS_KanpaWater()
{
	enable = true;
	stateID = CS_KanpaSTATENAME_WATER;
	o2_counter_max = 20;
}

void CS_KanpaWater::State()
{
	auto we = e.lock();
	if (!we)
		return;

	auto mychar = std::static_pointer_cast<CS_Kanpa>(we);
	auto& stateGravity = mychar->stateGravity;
	mychar->SetPhysice(we->cbRect.inWater);
	if (we->cbRect.pxaBottom == 0x12)
		mychar->SetPhysice(true);

	//ˮˮЧ
	if (we->cbRect.inWater)
	{
		o2_show = true;
		o2_hide_counter = 60;
		if (fallToWater && setSplash && we->vy >= stateGravity.max_fall_speed / 2)
		{
			//ˮ
			auto nE = we->gameFunc->GameCreateEntity(L"pe_splash");
			nE->x = we->x;
			nE->y = we->y;
			//ҽ
			if (we->cbRect.inLava)
				nE->color = RGBA(0xff, 0, 0, 0xff);
			we->gameFunc->SetEntity(we, nE);
			fallToWater = false;
		}
		else
		{
			//ٶδﵽȻˮ
			setSplash = false;
		}
		//ֵ
		if (o2_counter > 0)
			o2_counter--;
		if (o2_counter == 0)
		{
			o2_counter = o2_counter_max;
			if (o2 > 0)
				o2--;
		}
		if (o2 == 0)
		{
			//Ϣ
			mychar->ChangeState(mychar->stateDrown.GetStateID());
			if (we->gameFunc->StartEvent)
			{
				we->gameFunc->StopMusic();
				we->gameFunc->StartEvent(we->gameFunc->gameScript, L"Drown", L"tBoot");
			}
		}
	}
	else
	{
		//ˮ
		fallToWater = true;
		setSplash = true;
		//ʾ
		o2 = 100;
		if (o2_hide_counter > 0)
			o2_hide_counter--;
		if (o2_hide_counter == 0)
			o2_show = false;
	}
	//UI
	if (we->gameFunc)
	{
		int playerIndex = we->gameFunc->GetPlayerIndex(we->gameFunc->game, we);
		if (playerIndex < 0)
			return;
		auto& ui = *we->gameFunc->GetPlayerUIData(we->gameFunc->gameUI, playerIndex);
		ui.o2_show = o2_show;
		ui.o2 = o2;
		ui.o2_effect = we->cbRect.inWater;
	}
}
